@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Function );
 
-our $VERSION = '0.46_001';
+our $VERSION = '0.46_002';
 
 use Socket 1.93 qw(
    AI_NUMERICHOST AI_PASSIVE
@@ -76,7 +76,7 @@ This object is used indirectly via an C<IO::Async::Loop>:
     },
  );
 
- $loop->loop_forever;
+ $loop->run;
 
 =head1 DESCRIPTION
 
@@ -280,6 +280,9 @@ sub getaddrinfo
    $args{family}   = _getfamilybyname( $args{family} )     if defined $args{family};
    $args{socktype} = _getsocktypebyname( $args{socktype} ) if defined $args{socktype};
 
+   # Clear any other existing but undefined hints
+   defined $args{$_} or delete $args{$_} for keys %args;
+
    # It's likely this will succeed with AI_NUMERICHOST if host contains only
    # [\d.] (IPv4) or [[:xdigit:]:] (IPv6)
    # Technically we should pass AI_NUMERICSERV but not all platforms support
@@ -535,6 +538,9 @@ register_resolver getaddrinfo_hash => sub {
    $args{family}   = _getfamilybyname( $args{family} )     if defined $args{family};
    $args{socktype} = _getsocktypebyname( $args{socktype} ) if defined $args{socktype};
 
+   # Clear any other existing but undefined hints
+   defined $args{$_} or delete $args{$_} for keys %args;
+
    my ( $err, @addrs ) = _getaddrinfo( $host, $service, \%args );
 
    die "$err\n" if $err;
